<?php

////////////////////////////////////////////////////////////////////
// Settig Theme-options
////////////////////////////////////////////////////////////////////
include_once( trailingslashit( get_template_directory() ) . '/lib/plugin-activation.php' );  
include_once( trailingslashit( get_template_directory() ) . '/lib/theme-config.php' );

add_action( 'after_setup_theme', 'blogr_setup' );

if( !function_exists( 'blogr_setup' ) ) :
function blogr_setup() {
  
  // Theme lang
  load_theme_textdomain( 'blogr', get_template_directory() . '/languages' );

  // Add Title Tag Support
  add_theme_support( 'title-tag' );
  
  // Register Menus
  register_nav_menus(
  array(
       'main_menu' => __('Main Menu', 'blogr'),
        )
  );
  
  // Add support for a featured image and the size
  add_theme_support( 'post-thumbnails' );
  set_post_thumbnail_size(300,300, true);
  add_image_size( 'blogr_home', 500, 333, true );
  add_image_size( 'blogr_featured', 832, 300, true );
  add_image_size( 'blogr_single', 1600, 400, true );
  
      
  // Adds RSS feed links to for posts and comments.
  add_theme_support( 'automatic-feed-links' );

  // Set Content Width
  if ( ! isset( $content_width ) ) $content_width = 800;  
  
  // Display a admin notices
  add_action('admin_notices', 'blogr_admin_notice');
    function blogr_admin_notice() {
        global $current_user;
        $blogr_pro = 'http://themes4wp.com/product/blogr-pro/';
            $user_id = $current_user->ID;
            /* Check that the user hasn't already clicked to ignore the message */
        if ( ! get_user_meta($user_id, 'blogr_ignore_notice') ) {
            echo '<div class="updated notice-info point-notice" style="position:relative;"><p>'; 
            printf(__('Like BlogR theme? You will <strong>LOVE BlogR PRO</strong>!','blogr').'<a href="'.esc_url($blogr_pro).'" target="_blank">&nbsp;'.__('Click here for all the exciting features.','blogr').'</a><a href="%1$s" class="dashicons dashicons-dismiss dashicons-dismiss-icon" style="position: absolute; top: 8px; right: 8px; color: #222; opacity: 0.4; text-decoration: none !important;"></a>', '?blogr_notice_ignore=0');
            echo "</p></div>";
        }
  }

  add_action('admin_init', 'blogr_notice_ignore');
    function blogr_notice_ignore() {
        global $current_user;
            $user_id = $current_user->ID;
            /* If user clicks to ignore the notice, add that to their user meta */
            if ( isset($_GET['blogr_notice_ignore']) && '0' == $_GET['blogr_notice_ignore'] ) {
                add_user_meta($user_id, 'blogr_ignore_notice', 'true', true);
        }
  }

  add_action( 'customize_controls_print_footer_scripts', 'blogr_pro_banner' );
    function blogr_pro_banner() {
        $blogr_pro = 'http://themes4wp.com/product/blogr-pro/';
        echo '<a href="'.esc_url($blogr_pro).'" id="pro-banner" style="display: none; margin-top: 10px; background: #192429;" target="_blank"><img src="'.get_template_directory_uri().'/img/blogr-pro.jpg" /></a>';
        echo '<script type="text/javascript">jQuery(document).ready(function($) { $("#pro-banner").appendTo("#customize-info").css("display", "block"); });</script>';
  }
}
endif;


////////////////////////////////////////////////////////////////////
// Enqueue Styles 
////////////////////////////////////////////////////////////////////
function blogr_theme_stylesheets() {

        wp_enqueue_style('blogr-bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), '1', 'all' );
        wp_enqueue_style( 'blogr-stylesheet', get_stylesheet_uri(), array(), '1', 'all' );
        // load Font Awesome css
	      wp_enqueue_style( 'blogr-font-awesome', get_template_directory_uri() . '/css/font-awesome.min.css', array(), false );
}
add_action('wp_enqueue_scripts', 'blogr_theme_stylesheets');

////////////////////////////////////////////////////////////////////
// Register Bootstrap JS with jquery
////////////////////////////////////////////////////////////////////
function blogr_theme_js() {
        wp_enqueue_script('blogr-bootstrap-js', get_template_directory_uri() . '/js/bootstrap.js',array( 'jquery' ),true );
        wp_enqueue_script('blogr-theme-js', get_template_directory_uri() . '/js/customscript.js',array( 'jquery' ),true );
}
add_action('wp_enqueue_scripts', 'blogr_theme_js');


////////////////////////////////////////////////////////////////////
// Register Custom Navigation Walker include custom menu widget to use walkerclass
////////////////////////////////////////////////////////////////////

require_once('lib/wp_bootstrap_navwalker.php');

////////////////////////////////////////////////////////////////////
// Theme Info page
////////////////////////////////////////////////////////////////////

    if (is_admin()) {
    	require_once(trailingslashit( get_template_directory() ) . '/lib/theme-info.php');
    }

////////////////////////////////////////////////////////////////////
// Register the Sidebar(s)
////////////////////////////////////////////////////////////////////
add_action( 'widgets_init', 'blogr_widgets_init' );
function blogr_widgets_init() {
        register_sidebar(
            array(
            'name' => __('Right Sidebar', 'blogr'),
            'id' => 'right-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));

        register_sidebar(
            array(
            'name' => __('Left Sidebar', 'blogr'),
            'id' => 'left-sidebar',
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));
        
        register_sidebar(
            array(
            'name' => __('Area After First Post', 'blogr'),
            'id' => 'post-area',
            'description'     => __( 'Suitable for text widget.', 'blogr' ),
            'before_widget' => '<aside id="%1$s" class="widget %2$s">',
            'after_widget' => '</aside>',
            'before_title' => '<h3>',
            'after_title' => '</h3>',
        ));
}
////////////////////////////////////////////////////////////////////
// Register hook and action to set Main content area col-md- width based on sidebar declarations
////////////////////////////////////////////////////////////////////

add_action( 'blogr_main_content_width_hook', 'blogr_main_content_width_columns');

function blogr_main_content_width_columns () {

    $columns = '12';

    if (get_theme_mod( 'rigth-sidebar-check', 1 ) != 0 ) {
        $columns = $columns - esc_attr(get_theme_mod( 'right-sidebar-size', 3 ));
    }

    if (get_theme_mod( 'left-sidebar-check', 0 ) != 0 ) {
        $columns = $columns - esc_attr(get_theme_mod( 'left-sidebar-size', 3 ));
    }

    echo $columns;
}

function blogr_main_content_width() {
    do_action('blogr_main_content_width_hook');
}



////////////////////////////////////////////////////////////////////
// Breadcrumbs
////////////////////////////////////////////////////////////////////
function blogr_breadcrumb() {
	global $post, $wp_query;
	// schema link
	$home = __('Home', 'blogr');
	$delimiter = ' &raquo; ';
	$homeLink = home_url();
	if (is_home() || is_front_page()) {
		// no need for breadcrumbs in homepage
	}
	else {
		echo '<div id="breadcrumbs" >';
		echo '<div class="breadcrumbs-inner text-right">';
		// main breadcrumbs lead to homepage
		echo '<span><a href="' . esc_url($homeLink) . '">' . '<i class="fa fa-home"></i><span>' . esc_attr($home) . '</span>' . '</a></span>' . $delimiter . ' ';
		// if blog page exists
		if (get_page_by_path('blog')) {
			if (!is_page('blog')) {
				echo '<span><a href="' . get_permalink(get_page_by_path('blog')) . '">' . '<span>' . _x( 'Blog', 'Breadcrumbs', 'blogr' ).'</span></a></span>' . $delimiter . ' ';
			}
		}
		if (is_category()) {
			$thisCat = get_category(get_query_var('cat') , false);
			if ($thisCat->parent != 0) {
				$category_link = get_category_link($thisCat->parent);
				echo '<span><a href="' . $category_link . '">' . '<span>' . get_cat_name($thisCat->parent) . '</span>' . '</a></span>' . $delimiter . ' ';
			}
			$category_id = get_cat_ID(single_cat_title('', false));
			$category_link = get_category_link($category_id);
			echo '<span><a href="' . $category_link . '">' . '<span>' . single_cat_title('', false) . '</span>' . '</a></span>';
		}
		elseif (is_single() && !is_attachment()) {
			if (get_post_type() != 'post') {
				$post_type = get_post_type_object(get_post_type());
				$slug = $post_type->rewrite;
				echo '<span><a href="' . esc_url($homeLink) . '/' . $slug['slug'] . '">' . '<span>' . $post_type->labels->singular_name . '</span>' . '</a></span>';
				echo ' ' . $delimiter . ' ' . get_the_title();
			}
			else {
				$category = get_the_category();
				if ($category) {
					foreach($category as $cat) {
						echo '<span><a href="' . get_category_link($cat->term_id) . '">' . '<span>' . $cat->name . '</span>' . '</a></span>' . $delimiter . ' ';
					}
				}
				echo get_the_title();
			}
		}
		elseif (!is_single() && !is_page() && get_post_type() != 'post' && !is_404() && !is_search()) {
			$post_type = get_post_type_object(get_post_type());
			echo $post_type->labels->singular_name;
		}
		elseif (is_attachment()) {
			$parent = get_post($post->post_parent);
			echo '<span><a href="' . get_permalink($parent) . '">' . '<span>' . $parent->post_title . '</span>' . '</a></span>';
			echo ' ' . $delimiter . ' ' . get_the_title();
		}
		elseif (is_page() && !$post->post_parent) {
			$get_post_slug = $post->post_name;
			$post_slug = str_replace('-', ' ', $get_post_slug);
			echo '<span><a href="' . get_permalink() . '">' . '<span>' . ucfirst($post_slug) . '</span>' . '</a></span>';
		}
		elseif (is_page() && $post->post_parent) {
			$parent_id = $post->post_parent;
			$breadcrumbs = array();
			while ($parent_id) {
				$page = get_page($parent_id);
				$breadcrumbs[] = '<span><a href="' . get_permalink($page->ID) . '">' . '<span>' . get_the_title($page->ID) . '</span>' . '</a></span>';
				$parent_id = $page->post_parent;
			}
			$breadcrumbs = array_reverse($breadcrumbs);
			for ($i = 0; $i < count($breadcrumbs); $i++) {
				echo $breadcrumbs[$i];
				if ($i != count($breadcrumbs) - 1) echo ' ' . $delimiter . ' ';
			}
			echo $delimiter . '<span><a href="' . get_permalink() . '">' . '<span>' . the_title_attribute('echo=0') . '</span>' . '</a></span>';
		}
		elseif (is_tag()) {
			$tag_id = get_term_by('name', single_cat_title('', false) , 'post_tag');
			if ($tag_id) {
				$tag_link = get_tag_link($tag_id->term_id);
			}
			echo '<span><a href="' . $tag_link . '">' . '<span>' . single_cat_title('', false) . '</span>' . '</a></span>';
		}
		elseif (is_author()) {
			global $author;
			$userdata = get_userdata($author);
			echo '<span><a href="' . get_author_posts_url($userdata->ID) . '">' . '<span>' . $userdata->display_name . '</span>' . '</a></span>';
		}
		elseif (is_404()) {
			echo __('Error 404', 'blogr');
		}
		elseif (is_search()) {
			echo 'Search results for "' . get_search_query() . '"';
		}
		elseif (is_day()) {
			echo '<span><a href="' . get_year_link(get_the_time('Y')) . '">' . '<span>' . get_the_time('Y') . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . get_month_link(get_the_time('Y') , get_the_time('m')) . '">' . '<span>' . get_the_time('F') . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . get_day_link(get_the_time('Y') , get_the_time('m') , get_the_time('d')) . '">' . '<span>' . get_the_time('d') . '</span>' . '</a></span>';
		}
		elseif (is_month()) {
			echo '<span><a href="' . get_year_link(get_the_time('Y')) . '">' . '<span>' . get_the_time('Y') . '</span>' . '</a></span>' . $delimiter . ' ';
			echo '<span><a href="' . get_month_link(get_the_time('Y') , get_the_time('m')) . '">' . '<span>' . get_the_time('F') . '</span>' . '</a></span>';
		}
		elseif (is_year()) {
			echo '<span><a href="' . get_year_link(get_the_time('Y')) . '">' . '<span>' . get_the_time('Y') . '</span>' . '</a></span>';
		}
		if (get_query_var('paged')) {
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo ' (';
			echo __('Page', 'blogr') . ' ' . get_query_var('paged');
			if (is_category() || is_day() || is_month() || is_year() || is_search() || is_tag() || is_author()) echo ')';
		}
		echo '</div></div>';
	}
}


////////////////////////////////////////////////////////////////////
// Display navigation to next/previous pages when applicable
////////////////////////////////////////////////////////////////////
if ( ! function_exists( 'blogr_content_nav' ) ) :
function blogr_content_nav( $nav_id ) {
	global $wp_query, $post;

	// Don't print empty markup on single pages if there's nowhere to navigate.
	if ( is_single() ) {
		$previous = ( is_attachment() ) ? get_post( $post->post_parent ) : get_adjacent_post( false, '', true );
		$next = get_adjacent_post( false, '', false );

		if ( ! $next && ! $previous )
			return;
	}

	// Don't print empty markup in archives if there's only one page.
	if ( $wp_query->max_num_pages < 2 && ( is_home() || is_archive() || is_search() ) )
		return;

	$nav_class = ( is_single() ) ? 'post-navigation' : 'paging-navigation';

	?>
	<nav role="navigation" id="<?php echo esc_attr( $nav_id ); ?>" class="<?php echo $nav_class; ?>">
		<div class="screen-reader-text"><?php _e( 'Post navigation', 'blogr' ); ?></div>
		<div class="pager">

		<?php if ( is_single() ) : // navigation links for single posts ?>

			<div class="post-navigation row">
        	<div class="post-previous col-md-6"><?php previous_post_link( '%link', '<span class="meta-nav">'. __( 'Previous:', 'blogr' ).'</span> %title' ); ?></div>
        	<div class="post-next col-md-6"><?php next_post_link( '%link', '<span class="meta-nav">'. __( 'Next:', 'blogr' ).'</span> %title' ); ?></div>
      </div>

		<?php elseif ( $wp_query->max_num_pages > 1 && ( is_home() || is_archive() || is_search() ) ) : // navigation links for home, archive, and search pages ?>

			<?php if ( get_next_posts_link() ) : ?>
			<li class="nav-previous previous btn btn-default"><?php next_posts_link( __( 'Older posts', 'blogr' ) ); ?></li>
			<?php endif; ?>

			<?php if ( get_previous_posts_link() ) : ?>
			<li class="nav-next next btn btn-default"><?php previous_posts_link( __( 'Newer posts', 'blogr' ) ); ?></li>
			<?php endif; ?>

		<?php endif; ?>

		</div>
	</nav>
	<?php
}
endif; // content_nav

////////////////////////////////////////////////////////////////////
// Social links
////////////////////////////////////////////////////////////////////
if ( ! function_exists( 'blogr_social_links' ) ) :
/**
 * This function is for social links display on header
 * Get links through Theme Options
 */
function blogr_social_links() {
   $twp_social_links = array( 'twp_social_facebook' 	=> __( 'Facebook', 'blogr' ),
									'twp_social_twitter' 		=> __( 'Twitter', 'blogr' ),
									'twp_social_google' 	=> __( 'Google-Plus' , 'blogr' ),
									'twp_social_instagram' 	=> __( 'Instagram', 'blogr' ),
									'twp_social_pin' 	=> __( 'Pinterest', 'blogr' ),
									'twp_social_youtube' 		=> __( 'YouTube', 'blogr' ),
									'twp_social_reddit' 	=> __( 'Reddit', 'blogr' ),
							 	);
	?>
	<div class="social-links col-sm-4">
		<ul>
		<?php
			$i=0;
			$twp_links_output = '';
			foreach( $twp_social_links as $key => $value ) {
				$link = get_theme_mod( $key , '' );
				if ( !empty( $link ) ) {
					
					$twp_links_output .=
						'<li><a href="'.esc_url( $link ).'" target="_blank"><i class="fa fa-'.strtolower($value).'"></i></a></li>';
				}
				$i++;
			}
			echo $twp_links_output;
		?>
		</ul>
	</div><!-- .social-links -->
	<?php
}
endif;

////////////////////////////////////////////////////////////////////
// Pagination
////////////////////////////////////////////////////////////////////
function blogr_pagination() {
    global $wp_query;
    $big = 999999999;
    $pages = paginate_links(array(
        'base' => str_replace($big, '%#%', esc_url(get_pagenum_link($big))),
        'format' => '?page=%#%',
        'current' => max(1, get_query_var('paged')),
        'total' => $wp_query->max_num_pages,
        'prev_next' => false,
        'type' => 'array',
        'prev_next' => TRUE,
        'prev_text' => __('&larr; Previous', 'blogr' ),
        'next_text' => __('Next &rarr;', 'blogr' ),
            ));
    if (is_array($pages)) {
        $current_page = ( get_query_var('paged') == 0 ) ? 1 : get_query_var('paged');
        echo '<ul class="pagination">';
        foreach ($pages as $i => $page) {
            if ($current_page == 1 && $i == 0) {
                echo "<li class='active'>$page</li>";
            } else {
                if ($current_page != 1 && $current_page == $i) {
                    echo "<li class='active'>$page</li>";
                } else {
                    echo "<li>$page</li>";
                }
            }
        }
        echo '</ul>';
    }
}

////////////////////////////////////////////////////////////////////
// Excerpt functions
////////////////////////////////////////////////////////////////////
function blogr_excerpt_length( $length ) {
	return 25;
}
add_filter( 'excerpt_length', 'blogr_excerpt_length', 999 );

function blogr_excerpt_more( $more ) {
	return '...';
}
add_filter('excerpt_more', 'blogr_excerpt_more');     